/*
******************************************************************************
*  Name     : BitmapUtilsDemoContainer.cpp
*  Date     : 30.7.04
*  Description:
*     Container Control.
*     
*  Copyright: Susi Games, Germany
******************************************************************************
*/


#include "BitmapUtilsDemoContainer.h"

#include <eikenv.h>

void CBitmapUtilsDemoContainer::ConstructL(const TRect& aRect, CImageLoader* aImageLoader)
{
    CreateWindowL();
    SetRect(aRect);    
	iImageLoader = aImageLoader;

	
	// load the background
	iBmp1 = iImageLoader->LoadSusImage(1000);

	// load the items
	iBmp2 = iImageLoader->LoadSusImage(2000);
	iBmp3 = iImageLoader->LoadSusImage(2001);


	
	iEng = CBitmapUtilsDemoEng::NewL(iEikonEnv->WsSession(), 
                            *(CCoeEnv::Static()->ScreenDevice()), 
					           Window());

	iEng->SetBackgroundImage(iBmp1);
	iEng->SetForegroundBitmaps(iBmp2,iBmp3);
	
    ActivateL();

	// make this class observe changes of foreground
	CEikonEnv::Static()->AddForegroundObserverL( *this );
}


CBitmapUtilsDemoContainer::~CBitmapUtilsDemoContainer()
{
    if(iEng && iEng->Drawing())
		iEng->StopDrawing();
	delete iEng;
    iEng = NULL;

	iImageLoader->ReleaseImage(iBmp1);iBmp1 = NULL;
	iImageLoader->ReleaseImage(iBmp2);iBmp2 = NULL;
	iImageLoader->ReleaseImage(iBmp3);iBmp3 = NULL;
}


TInt CBitmapUtilsDemoContainer::CountComponentControls() const
{    
	return 0;
}


void CBitmapUtilsDemoContainer::Draw(const TRect& /*aRect*/) const
{
	// nothing to do, the engine draws for us...
}


void CBitmapUtilsDemoContainer::HandleControlEventL(
    CCoeControl* /*aControl*/,TCoeEvent /*aEventType*/)
{
}


TKeyResponse CBitmapUtilsDemoContainer::OfferKeyEventL(const TKeyEvent& aKeyEvent,TEventCode aType)
{
	if (aKeyEvent.iCode == '4' && aType==EEventKey)
    {
		iEng->ChangeLoopInterval(2000);
		return EKeyWasConsumed;
	}
	if (aKeyEvent.iCode == '6' && aType==EEventKey)
    {
		iEng->ChangeLoopInterval(-2000);
		return EKeyWasConsumed;
	}

	if (aKeyEvent.iCode == '5' && aType==EEventKey)
    {
		if (iEng->Drawing()) StopDrawing();
		else StartDrawingL();
		return EKeyWasConsumed;
	}


    return EKeyWasNotConsumed;
}


void CBitmapUtilsDemoContainer::HandleGainingForeground()
{
	if (!IsDrawing()) StartDrawingL();

}


void CBitmapUtilsDemoContainer::HandleLosingForeground()
{
	if (IsDrawing()) StopDrawing();
}


void CBitmapUtilsDemoContainer::StartDrawingL()
{    
	iEng->StartDrawingL();
}


void CBitmapUtilsDemoContainer::StopDrawing()
{    
	iEng->StopDrawing();    
}


TBool CBitmapUtilsDemoContainer::IsDrawing()
{    
	return iEng->Drawing();	
}

// End of File  
